@@ -3,7 +3,7 @@
 |''Description''|adaptor for interacting with TiddlyWeb|
 |''Author:''|FND|
 |''Contributors''|Chris Dent, Martin Budden|
-|''Version''|1.2.1|
+|''Version''|1.2.4|
 |''Status''|stable|
 |''Source''|http://svn.tiddlywiki.org/Trunk/association/adaptors/TiddlyWebAdaptor.js|
 |''CodeRepository''|http://svn.tiddlywiki.org/Trunk/association/|
@@ -20,8 +20,7 @@ This plugin includes [[jQuery JSON|http://code.google.com/p/jquery-json/]].
 //{{{
 (function($) {
 
-var adaptor;
-adaptor = config.adaptors.tiddlyweb = function() {}; //# set up alias
+var adaptor = config.adaptors.tiddlyweb = function() {};
 
 adaptor.prototype = new AdaptorBase();
 adaptor.serverType = "tiddlyweb";
@@ -252,8 +251,13 @@ adaptor.getTiddlerCallback = function(status, context, responseText, uri, xhr) {
 		}
 		context.tiddler.assign(context.tiddler.title, t.text, t.modifier,
 			Date.convertFromYYYYMMDDHHMM(t.modified), t.tags || [],
-			Date.convertFromYYYYMMDDHHMM(t.created), context.tiddler.fields); // XXX: merge extended fields!?
-		context.tiddler.fields["server.workspace"] = t.bag ? "bags/" + t.bag : "recipes/" + t.recipe; // XXX: bag is always supplied!?
+			Date.convertFromYYYYMMDDHHMM(t.created), context.tiddler.fields,
+			t.creator); // XXX: merge extended fields!?
+		context.tiddler.fields["server.bag"] = t.bag;
+		if(t.recipe) {
+			context.tiddler.fields["server.recipe"] = t.recipe;
+		}
+		context.tiddler.fields["server.workspace"] = "bags/" + t.bag;
 		context.tiddler.fields["server.page.revision"] = t.revision;
 		context.tiddler.fields["server.permissions"] = t.permissions.join(", ");
 	}
@@ -301,7 +305,8 @@ adaptor.prototype.putTiddler = function(tiddler, context, userParams, callback)
 	}
 	var uriTemplate = "%0/%1/%2/tiddlers/%3";
 	try {
-		var workspace = adaptor.resolveWorkspace(tiddler.fields["server.workspace"]);
+		context.workspace = context.workspace || tiddler.fields["server.workspace"];
+		var workspace = adaptor.resolveWorkspace(context.workspace);
 	} catch(ex) {
 		return adaptor.locationIDErrorMessage;
 	}
@@ -570,6 +575,8 @@ adaptor.generateETag = function(workspace, tiddler) {
 		var revision = tiddler.fields["server.page.revision"];
 		if(typeof revision == "undefined") {
 			revision = "0";
+		} else if(revision == "false") {
+			return null;
 		}
 		etag = [adaptor.normalizeTitle(workspace.name),
 			adaptor.normalizeTitle(tiddler.title), revision].join("/");
