@@ -2,7 +2,7 @@
 |''Name''|TiddlyWebConfig|
 |''Description''|configuration settings for TiddlyWebWiki|
 |''Author''|FND|
-|''Version''|0.7.5|
+|''Version''|0.8.1|
 |''Status''|stable|
 |''Source''|http://svn.tiddlywiki.org/Trunk/association/plugins/TiddlyWebConfig.js|
 |''License''|[[BSD|http://www.opensource.org/licenses/bsd-license.php]]|
@@ -23,6 +23,8 @@
 * disabled edit toolbar command for unauthorized users
 !!v0.7 (2009-09-11)
 * added revisions toolbar command
+!!v0.8 (2010-04-28)
+* added extension namespace caching state and providing getUserInfo function
 !Code
 ***/
 //{{{
@@ -36,21 +38,45 @@ if(window.location.protocol != "file:") {
 	config.options.chkAutoSave = true;
 }
 
-// initialize configuration
 var adaptor = tiddler.getAdaptor();
-var host = tiddler.fields["server.host"];
 var recipe = tiddler.fields["server.recipe"];
 var workspace = recipe ? "recipes/" + recipe : "bags/common";
+
+var plugin = config.extensions.tiddlyweb = {
+	serverVersion: null,
+	host: tiddler.fields["server.host"].replace(/\/$/, ""),
+	challengers: null,
+	username: null,
+
+	getUserInfo: function(callback) {
+		var _callback = function() {
+			callback({
+				name: plugin.username,
+				anon: plugin.username == "GUEST"
+			});
+		};
+		if(this.username) {
+			_callback();
+		} else {
+			var _statusCallback = function(context, userParams) {
+				statusCallback(context, userParams);
+				_callback();
+			};
+			adaptor.getStatus({ host: this.host }, null, _statusCallback);
+		}
+	}
+};
+
 config.defaultCustomFields = {
 	"server.type": tiddler.getServerType(),
-	"server.host": host,
+	"server.host": plugin.host,
 	"server.workspace": workspace
 };
 
 // modify toolbar commands
 
 config.shadowTiddlers.ToolbarCommands = config.shadowTiddlers.ToolbarCommands.
-	replace("closeTiddler ", "revisions closeTiddler ");
+	replace("syncing ", "revisions syncing ");
 
 config.commands.saveTiddler.isEnabled = function(tiddler) {
 	return hasPermission("write", tiddler);
@@ -79,19 +105,20 @@ var hasPermission = function(type, tiddler) {
 
 // retrieve server info
 var statusCallback = function(context, userParams) {
-	if(context.serverStatus) {
-		// set username
-		if(context.serverStatus.username) {
+	var status = context.serverStatus;
+	if(status) {
+		plugin.serverVersion = status.version;
+		if(status.username) {
+			plugin.username = status.username;
 			config.macros.option.propagateOption("txtUserName",
-				"value", context.serverStatus.username, "input");
+				"value", plugin.username, "input");
 		}
-		// retrieve challengers
-		if(context.serverStatus.challengers) {
-			config.adaptors.tiddlyweb.challengers = context.serverStatus.challengers;
+		if(status.challengers) {
+			plugin.challengers = status.challengers;
 		}
 	}
 };
-adaptor.getStatus({ host: host }, null, statusCallback);
+adaptor.getStatus({ host: plugin.host }, null, statusCallback);
 
 })();
 //}}}
